==> zzyj-outputvalcount-impl-3.0.0-20240428.040634-294-sources.jar: com/ejianc/business/outputvalcount/bean/CreditScoreEntity.java <==
package com.ejianc.business.outputvalcount.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 信用分
 * 
 * @author generator
 * 
 */
 @TableName("t_outputvalcount_credit_score")
public class CreditScoreEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="credit_score")
    private BigDecimal creditScore; // 信用分
    @TableField(value="rate_of_attendance_manager")
    private String rateOfAttendanceManager; // 项目经理考勤率
    @TableField(value="rate_of_attendance_worker")
    private String rateOfAttendanceWorker; // 工人考勤率
    
    
    

    public BigDecimal getCreditScore() {
        return creditScore;
    }

    public void setCreditScore(BigDecimal creditScore) {
        this.creditScore = creditScore;
    }
    public String getRateOfAttendanceManager() {
        return rateOfAttendanceManager;
    }

    public void setRateOfAttendanceManager(String rateOfAttendanceManager) {
        this.rateOfAttendanceManager = rateOfAttendanceManager;
    }
    public String getRateOfAttendanceWorker() {
        return rateOfAttendanceWorker;
    }

    public void setRateOfAttendanceWorker(String rateOfAttendanceWorker) {
        this.rateOfAttendanceWorker = rateOfAttendanceWorker;
    }
    
}

==> zzyj-outputvalcount-impl-3.0.0-20250527.032938-353-sources.jar: com/ejianc/business/outputvalcount/bean/CreditScoreEntity.java <==
package com.ejianc.business.outputvalcount.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 信用分
 * 
 * @author generator
 * 
 */
 @TableName("t_outputvalcount_credit_score")
public class CreditScoreEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="credit_score")
    private BigDecimal creditScore; // 信用分
    @TableField(value="rate_of_attendance_manager")
    private String rateOfAttendanceManager; // 项目经理考勤率
    @TableField(value="rate_of_attendance_worker")
    private String rateOfAttendanceWorker; // 工人考勤率
    @TableField(value="rank")
    private Integer rank; //排名
    @TableField(value="bill_code")
    private String billCode; // 单据编码

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Integer getRank() {
        return rank;
    }

    public void setRank(Integer rank) {
        this.rank = rank;
    }
    
    

    public BigDecimal getCreditScore() {
        return creditScore;
    }

    public void setCreditScore(BigDecimal creditScore) {
        this.creditScore = creditScore;
    }
    public String getRateOfAttendanceManager() {
        return rateOfAttendanceManager;
    }

    public void setRateOfAttendanceManager(String rateOfAttendanceManager) {
        this.rateOfAttendanceManager = rateOfAttendanceManager;
    }
    public String getRateOfAttendanceWorker() {
        return rateOfAttendanceWorker;
    }

    public void setRateOfAttendanceWorker(String rateOfAttendanceWorker) {
        this.rateOfAttendanceWorker = rateOfAttendanceWorker;
    }
    
}
